@@ -106,6 +106,9 @@ class VaspErrorHandler(ErrorHandler):
             actions.append({"dict": "INCAR",
                             "action": {"_set": {"SYMPREC": 1e-8}}})
 
+        if "brmix" in self.errors and "NELECT" in vi["INCAR"]:
+            #brmix error always shows up after DAV steps if NELECT is specified
+            self.errors.remove("brmix")
         if "brmix" in self.errors or "zpotrf" in self.errors:
             actions.append({"dict": "INCAR",
                             "action": {"_set": {"ISYM": 0}}})
@@ -121,7 +124,8 @@ class VaspErrorHandler(ErrorHandler):
             actions.append({"dict": "INCAR",
                             "action": {"_set": {"LREAL": False}}})
 
-        if "tetirr" in self.errors or "incorrect_shift" in self.errors:
+        if "tetirr" in self.errors or "incorrect_shift" in self.errors or \
+                    "rot_matrix" in self.errors:
             actions.append({"dict": "KPOINTS",
                             "action": {"_set": {"generation_style": "Gamma"}}})
 
@@ -136,16 +140,10 @@ class VaspErrorHandler(ErrorHandler):
             actions.append({"dict": "POSCAR",
                             "action": {"_set": {"structure": new_s.to_dict}},
                             "transformation": trans.to_dict})
-
-        if "rot_matrix" in self.errors or "pricel" in self.errors:
-            s = vi["POSCAR"].structure
-            trans = PerturbStructureTransformation(0.05)
-            new_s = trans.apply_transformation(s)
-            actions.append({"dict": "POSCAR",
-                            "action": {"_set": {"structure": new_s.to_dict}},
-                            "transformation": trans.to_dict})
+             
+        if "pricel" in self.errors:
             actions.append({"dict": "INCAR",
-                            "action": {"_set": {"SYMPREC": 1e-8}}})
+                            "action": {"_set": {"SYMPREC": 1e-8, "ISYM": 0}}})
 
         if "brions" in self.errors:
             potim = float(vi["INCAR"].get("POTIM", 0.5)) + 0.1
@@ -571,4 +569,6 @@ class WalltimeHandler(ErrorHandler):
 
 @deprecated(replacement=WalltimeHandler)
 class PBSWalltimeHandler(WalltimeHandler):
-    pass
\ No newline at end of file
+
+    def __init__(self, buffer_time=300):
+        WalltimeHandler.__init__(self, None, buffer_time=buffer_time)
\ No newline at end of file
